@@ -9,7 +9,6 @@
 
 #include <QThread>
 
-#include <KAboutData>
 #include <KConfigGroup>
 #include <KSharedConfig>
 
@@ -21,8 +20,6 @@
 #include "DocumentSaver.h"
 #include "DocumentPrinter.h"
 #include "OCREngine.h"
-#include "skanpage_config.h"
-#include "skanpage_state.h"
 #include "skanpage_debug.h"
 
 class SkanpagePrivate {
